window.Gleam.initSearch([{"doc":"randomlib","title":"randomlib","content":"# randomlib\n\n[![Package Version](https://img.shields.io/hexpm/v/randomlib)](https://hex.pm/packages/randomlib)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/randomlib/)\n\nA random number library for Gleam\n\nThis package provides various function to generate random output for different types\nThe random generation should be the same between Erlang and Javascript targets\n\n```sh\ngleam add randomlib@1\n```\n```gleam\nimport randomlib\n\npub fn main() {\n  randomlib.choice(randomlib.new(), [&quot;Red&quot;, &quot;Green&quot;, &quot;Blue&quot;])\n\n  let #(val, rnd) = randomlib.next_byte(randomlib.with_seed(13470613))\n  let #(val2, rnd) = randomlib.next_float(rnd)\n\n  io.debug(val)\n  io.debug(val2)\n\n}\n// -&gt; 50\n// -&gt; 0.9460694304884285\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/randomlib&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"randomlib","title":"Random","content":"pub opaque type Random\n\n\nSynonyms:\nrandomlib.Random\nrandomlib Random","url":"randomlib.html#Random"},{"doc":"randomlib","title":"byte_iterator","content":"pub fn byte_iterator(rnd: Random) -&gt; Iterator(Int)\n Returns an iterated that generates byte in Int form when iterated\n Note that the random seed is internally updated but there is no ability\n to extract the updated seed\nSynonyms:\nrandomlib.byte_iterator\nrandomlib byte_iterator","url":"randomlib.html#byte_iterator"},{"doc":"randomlib","title":"choice","content":"pub fn choice(\n  rnd: Random,\n  choices: List(a),\n) -&gt; Result(Iterator(a), Nil)\n If non-empty choices list is provided, returns an iterator that performs a uniformly \n distributed selection from the the items in the list\n If no choices are passed an Error(Nil) is returned\nSynonyms:\nrandomlib.choice\nrandomlib choice","url":"randomlib.html#choice"},{"doc":"randomlib","title":"float_iterator","content":"pub fn float_iterator(rnd: Random) -&gt; Iterator(Float)\n Returns an iterated that generates uniformly distributed Floats when iterated\n Note that the random seed is internally updated but there is no ability\n to extract the updated seed\nSynonyms:\nrandomlib.float_iterator\nrandomlib float_iterator","url":"randomlib.html#float_iterator"},{"doc":"randomlib","title":"new","content":"pub fn new() -&gt; Random\n Creates a new random seed with distinctness set using the\n current time, nominally in nanoseconds.\n Please note that the actual timings will be microseconds\n for erland and milliseconds for javascript, so any new random\n seeds generated in that same time scale will be the same\nSynonyms:\nrandomlib.new\nrandomlib new","url":"randomlib.html#new"},{"doc":"randomlib","title":"next","content":"pub fn next(rnd: Random, bits: Int) -&gt; #(BigInt, Random)\n Returns a tuple containing a BigInt of size n bits and the\n updated random seed\n Note that this hasn&#39;t been fully tested to generate\n uniformly distributed values\nSynonyms:\nrandomlib.next\nrandomlib next","url":"randomlib.html#next"},{"doc":"randomlib","title":"next_bool","content":"pub fn next_bool(rnd: Random) -&gt; #(Bool, Random)\n Returns a tuple containing a uniformly distributed Bool and \n the updated random seed\nSynonyms:\nrandomlib.next_bool\nrandomlib next_bool","url":"randomlib.html#next_bool"},{"doc":"randomlib","title":"next_byte","content":"pub fn next_byte(rnd: Random) -&gt; #(Int, Random)\n Returns a tuple containing a byte (0-255) in Int form and the\n updated random seed\nSynonyms:\nrandomlib.next_byte\nrandomlib next_byte","url":"randomlib.html#next_byte"},{"doc":"randomlib","title":"next_bytes","content":"pub fn next_bytes(rnd: Random, n: Int) -&gt; #(List(Int), Random)\n Returns a tuple containing a list of n bytes in Int form and\n the updated random seed\n Passing n &lt;= 0 will return an empty list\nSynonyms:\nrandomlib.next_bytes\nrandomlib next_bytes","url":"randomlib.html#next_bytes"},{"doc":"randomlib","title":"next_float","content":"pub fn next_float(rnd: Random) -&gt; #(Float, Random)\n Returns a tuple containing a uniformly distributed float \n between 0.0 (inclusive) and 1.0 (exclusive) and the updated random seed\nSynonyms:\nrandomlib.next_float\nrandomlib next_float","url":"randomlib.html#next_float"},{"doc":"randomlib","title":"next_int","content":"pub fn next_int(\n  rnd: Random,\n  limit: Int,\n) -&gt; Result(#(Int, Random), Random)\n Returns a result containing either a tuple containing a uniformly distributed\n Int (where int is 31 bits unsigned) and the updated random seed or an error\n containing the random seed (currently not updated)\nSynonyms:\nrandomlib.next_int\nrandomlib next_int","url":"randomlib.html#next_int"},{"doc":"randomlib","title":"with_seed","content":"pub fn with_seed(seed: Int) -&gt; Random\n Creates a new random seed based on the specified seed provided\nSynonyms:\nrandomlib.with_seed\nrandomlib with_seed","url":"randomlib.html#with_seed"},{"doc":"randomlib","title":"randomlib","content":"","url":"randomlib.html"}]);